@@ -1801,3 +1801,6 @@ def _typecheckingstub__3572ac292b4bd9b3dc808ba9caa4797adcb64703144da90f4ad010fde
 ) -> None:
     """Type checking stubs"""
     pass
+
+for cls in [IDevContainerEnvironment]:
+    typing.cast(typing.Any, cls).__protocol_attrs__ = typing.cast(typing.Any, cls).__protocol_attrs__ - set(['__jsii_proxy_class__', '__jsii_type__'])
